==> ubuntuone-storage-protocol_1.2.0.orig.tar.gz: ubuntuone-storage-protocol-1.2.0/tests/test_errors.py <==
# -*- coding: utf-8 -*-
#
# Author: Natalia B. Bidart <natalia.bidart@canonical.com>
#
# Copyright (C) 2010 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3,
# as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""Tests for errors module."""

import unittest

from ubuntuone.storageprotocol import errors, protocol_pb2

REQ_ARGS = dict(request=None, message=protocol_pb2.Message())

HIGH_LEVEL_ERRORS = {errors.StorageProtocolErrorSizeTooBig: dict(),
                     errors.StorageProtocolProtocolError: dict(),
                     errors.StorageRequestError: REQ_ARGS,
                     errors.RequestCancelledError: dict()}


class ErrorsTestCase(unittest.TestCase):
    """Basic testing of errors mapping."""

    def setUp(self):
        """Init."""

    def test_exceptions_are_storage_protocol_error(self):
        """High level exceptions inherit from StorageProtocolError."""
        for e, args in HIGH_LEVEL_ERRORS.iteritems():
            self.assertTrue(isinstance(e(**args), errors.StorageProtocolError),
                            "%r must inherit from StorageProtocolError" % e)

    def test_mapping(self):
        """Protocol's specific exceptions are correct."""
        for code_error, proto_error in errors._error_mapping.iteritems():
            self.assertTrue(isinstance(proto_error(**REQ_ARGS),
                            errors.StorageRequestError),
                            "%r must inherit from StorageRequestError" %
                             proto_error)
            self.assertEqual(proto_error, errors.error_to_exception(code_error))

==> ubuntuone-storage-protocol_1.4.0.orig.tar.gz: ubuntuone-storage-protocol-1.4.0/tests/test_errors.py <==
# -*- coding: utf-8 -*-
#
# Author: Natalia B. Bidart <natalia.bidart@canonical.com>
#
# Copyright (C) 2010 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License version 3,
# as published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""Tests for errors module."""

import unittest
import uuid

from ubuntuone.storageprotocol import errors, protocol_pb2

REQ_ARGS = dict(request=None, message=protocol_pb2.Message())

HIGH_LEVEL_ERRORS = {errors.StorageProtocolErrorSizeTooBig: dict(),
                     errors.StorageProtocolProtocolError: dict(),
                     errors.StorageRequestError: REQ_ARGS,
                     errors.RequestCancelledError: dict()}


class ErrorsTestCase(unittest.TestCase):
    """Basic testing of errors mapping."""

    def setUp(self):
        """Init."""

    def test_exceptions_are_storage_protocol_error(self):
        """High level exceptions inherit from StorageProtocolError."""
        for e, args in HIGH_LEVEL_ERRORS.iteritems():
            self.assertTrue(isinstance(e(**args), errors.StorageProtocolError),
                            "%r must inherit from StorageProtocolError" % e)

    def test_mapping(self):
        """Protocol's specific exceptions are correct."""
        for code_error, proto_error in errors._error_mapping.iteritems():
            self.assertTrue(isinstance(proto_error(**REQ_ARGS),
                            errors.StorageRequestError),
                            "%r must inherit from StorageRequestError" %
                             proto_error)
            self.assertEqual(proto_error, errors.error_to_exception(code_error))

    def test_quota_exceed_error(self):
        """QuotaExceeded error must have quota info."""
        SHARE = uuid.uuid4()
        message = protocol_pb2.Message()
        message.error.type = protocol_pb2.Error.QUOTA_EXCEEDED
        message.free_space_info.share_id = str(SHARE)
        message.free_space_info.free_bytes = 10
        e = errors.QuotaExceededError(None, message)
        self.assertEqual(e.free_bytes, 10)
        self.assertEqual(e.share_id, SHARE)
